@@ -19,8 +19,8 @@ import gdb
 import os
 import os.path
 
-pythondir = '/builder/x86_legacy/build/staging_dir/toolchain-i386_pentium_gcc-7.3.0_musl/share/gcc-7.3.0/python'
-libdir = '/builder/x86_legacy/build/staging_dir/toolchain-i386_pentium_gcc-7.3.0_musl/i486-openwrt-linux-musl/lib'
+pythondir = '/builder/shared-workdir/build/staging_dir/toolchain-i386_pentium_gcc-7.3.0_musl/share/gcc-7.3.0/python'
+libdir = '/builder/shared-workdir/build/staging_dir/toolchain-i386_pentium_gcc-7.3.0_musl/i486-openwrt-linux-musl/lib'
 
 # This file might be loaded when there is no current objfile.  This
 # can happen if the user loads it manually.  In this case we don't
